@@ -1,6 +1,13 @@
+from pkg_resources import get_distribution
 from pydantic.schema import schema
 from typing import Dict
 
+VERSION = None
+
+try:
+    VERSION = '.'.join(get_distribution('honeybee_schema').version.split('.')[:3]),
+except:
+    pass
 
 # base open api dictionary for all schemas
 _base_open_api = {
@@ -8,7 +15,7 @@ _base_open_api = {
     "servers": [],
     "info": {
         "description": "",
-        "version": "1.3.0",
+        "version": VERSION,
         "title": "",
         "contact": {
             "name": "Ladybug Tools",
@@ -55,6 +62,9 @@ def get_openapi(
     if title:
         open_api['info']['title'] = title
 
+    if not version and not VERSION:
+        raise ValueError('Schema version must be specified as argument or from distribution metadata')
+
     if version:
         open_api['info']['version'] = version
 
@@ -81,6 +91,25 @@ def get_openapi(
         }
         tags.append(tag)
 
+        # sort properties order: put required parameters at begining of the list
+        s = schemas[name]
+        if not 'required' in s:
+            continue
+        properties = s['properties']
+        required = s['required']
+
+        sorted_props = {}
+        optional = {}
+        for prop, value in properties.items():
+            if prop in required:
+                sorted_props[prop] = value
+            else:
+                optional[prop] = value
+
+        sorted_props.update(optional)
+
+        s['properties'] = sorted_props
+
     tag_names.sort()
     open_api['tags'] = tags
     open_api['x-tagGroups'][0]['tags'] = tag_names
