@@ -1,8 +1,9 @@
 """Programtype Schema"""
-from pydantic import BaseModel, Field, validator, root_validator, constr
+from pydantic import Field, validator, root_validator, constr
 from typing import Union
 
 from ._base import NamedEnergyBaseModel
+from ..altnumber import Autocalculate
 
 
 class PeopleAbridged(NamedEnergyBaseModel):
@@ -43,29 +44,32 @@ class PeopleAbridged(NamedEnergyBaseModel):
         'value is 0.30.'
     )
 
-    latent_fraction: Union[float, str] = Field(
-        'autocalculate',
+    latent_fraction: Union[Autocalculate, float] = Field(
+        Autocalculate(),
         ge=0,
         le=1,
         description='Number for the latent fraction of heat gain due to people or '
-            'simply the word "autocalculate".'
+            'an Autocalculate object.'
     )
-
-    @validator('latent_fraction')
-    def check_string_latent_fraction(cls, v):
-        if not isinstance(v, float) and v != 'autocalculate':
-            raise ValueError('"{}" is not a valid entry for latent_fraction'.format(v))
     
     @root_validator
     def check_sum_fractions(cls, values): 
         "Ensure sum is less than 1."
         rad = values.get('radiant_fraction')
         latent = values.get('latent_fraction')
-        if latent is not None and latent != 'autocalculate':
-            assert rad + latent < 1, \
+        if latent is not None and isinstance(latent, float):
+            assert rad + latent <= 1, \
                 'Sum of radiant and latent fractions cannot be greater than 1.'
         return values
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['latent_fraction']['anyOf'] = [
+                    {"$ref": "#/components/schemas/Autocalculate"},
+                    {"type": "number", "minimum": 0, "maximum": 1}
+                ]
+
 
 class LightingAbridged(NamedEnergyBaseModel):
 
@@ -117,7 +121,7 @@ class LightingAbridged(NamedEnergyBaseModel):
         return_air = values.get('return_air_fraction')
         vis = values.get('visible_fraction')
         rad = values.get('radiant_fraction')
-        assert sum((return_air, vis, rad)) < 1, \
+        assert sum((return_air, vis, rad)) <= 1, \
             'Sum of visible, radiant, and return air fractions cannot be greater than 1.'
         return values
 
@@ -148,7 +152,7 @@ class _EquipmentBase(NamedEnergyBaseModel):
         ' by electric equipment. Default value is 0.'
     )
 
-    latent_fraction: Union[float, str] = Field(
+    latent_fraction: float = Field(
         0,
         ge=0,
         le=1,
@@ -171,7 +175,7 @@ class _EquipmentBase(NamedEnergyBaseModel):
         rad = values.get('radiant_fraction')
         latent = values.get('latent_fraction')
         lost = values.get('lost_fraction')
-        assert sum((rad, latent, lost)) < 1, \
+        assert sum((rad, latent, lost)) <= 1, \
             'Sum of radiant, latent, and lost fractions cannot be greater than 1.'
         return values
 
@@ -285,7 +289,7 @@ class SetpointAbridged(NamedEnergyBaseModel):
             'this schedule should be temperature in [C].'
     )
 
-    humidification_schedule: str = Field(
+    humidifying_schedule: str = Field(
         default=None,
         min_length=1,
         max_length=100,
@@ -293,7 +297,7 @@ class SetpointAbridged(NamedEnergyBaseModel):
             'in this schedule should be in [%].'
     )
 
-    dehumidification_schedule: str = Field(
+    dehumidifying_schedule: str = Field(
         default=None,
         min_length=1,
         max_length=100,
@@ -304,14 +308,14 @@ class SetpointAbridged(NamedEnergyBaseModel):
     @root_validator
     def check_both_himd_sch(cls, values): 
         "Ensure that the other humidity schedule is included when one is."
-        humid = values.get('humidification_schedule')
-        dehumid = values.get('dehumidification_schedule')
+        humid = values.get('humidifying_schedule')
+        dehumid = values.get('dehumidifying_schedule')
         if humid is not None:
-            assert dehumid is not None, 'When humidification_schedule is specified, ' \
-                'dehumidification_schedule must also be specified.'
+            assert dehumid is not None, 'When humidifying_schedule is specified, ' \
+                'dehumidifying_schedule must also be specified.'
         if dehumid is not None:
-            assert humid is not None, 'When dehumidification_schedule is specified, ' \
-                'humidification_schedule must also be specified.'
+            assert humid is not None, 'When dehumidifying_schedule is specified, ' \
+                'humidifying_schedule must also be specified.'
         return values
 
 
