@@ -1,11 +1,12 @@
 """Model energy properties."""
-from pydantic import BaseModel, Field, constr
+from pydantic import Field, constr
 from typing import List, Union
 from enum import Enum
 
+from .._base import NoExtraBaseModel
 from .constructionset import ConstructionSetAbridged
-from .construction import OpaqueConstructionAbridged, \
-    WindowConstructionAbridged, ShadeConstruction
+from .construction import OpaqueConstructionAbridged, WindowConstructionAbridged, \
+    ShadeConstruction, AirBoundaryConstructionAbridged
 from .material import EnergyMaterial, EnergyMaterialNoMass, \
     EnergyWindowMaterialGas, EnergyWindowMaterialGasCustom, \
     EnergyWindowMaterialGasMixture, EnergyWindowMaterialSimpleGlazSys, \
@@ -18,21 +19,23 @@ from .schedule import ScheduleTypeLimit, ScheduleRulesetAbridged, \
 from .hvac import IdealAirSystemAbridged
 
 
-class ShadeEnergyPropertiesAbridged(BaseModel):
+class ShadeEnergyPropertiesAbridged(NoExtraBaseModel):
 
     type: constr(regex='^ShadeEnergyPropertiesAbridged$') = \
         'ShadeEnergyPropertiesAbridged'
 
-    transmittance_schedule: str = Field(
+    construction:  str = Field(
         default=None,
         min_length=1,
         max_length=100,
         description='Name of a ShadeConstruction to set the reflectance and '
             'specularity of the Shade. If None, the construction is set by the'
-            'parent Room construction_set or the Model global_construction_set.'
+            'parent Room construction_set, the Model global_construction_set or '
+            '(in the case fo an orphaned shade) the EnergyPlus default of 0.2 '
+            'diffuse reflectance.'
     )
 
-    construction:  str = Field(
+    transmittance_schedule: str = Field(
         default=None,
         min_length=1,
         max_length=100,
@@ -42,7 +45,7 @@ class ShadeEnergyPropertiesAbridged(BaseModel):
     )
 
 
-class DoorEnergyPropertiesAbridged(BaseModel):
+class DoorEnergyPropertiesAbridged(NoExtraBaseModel):
 
     type: constr(regex='^DoorEnergyPropertiesAbridged$') = \
         'DoorEnergyPropertiesAbridged'
@@ -58,7 +61,7 @@ class DoorEnergyPropertiesAbridged(BaseModel):
     )
 
 
-class ApertureEnergyPropertiesAbridged(BaseModel):
+class ApertureEnergyPropertiesAbridged(NoExtraBaseModel):
 
     type: constr(regex='^ApertureEnergyPropertiesAbridged$') = \
         'ApertureEnergyPropertiesAbridged'
@@ -73,7 +76,7 @@ class ApertureEnergyPropertiesAbridged(BaseModel):
     )
 
 
-class FaceEnergyPropertiesAbridged(BaseModel):
+class FaceEnergyPropertiesAbridged(NoExtraBaseModel):
 
     type: constr(regex='^FaceEnergyPropertiesAbridged$') = \
         'FaceEnergyPropertiesAbridged'
@@ -88,7 +91,7 @@ class FaceEnergyPropertiesAbridged(BaseModel):
     )
 
 
-class RoomEnergyPropertiesAbridged(BaseModel):
+class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
 
     type: constr(regex='^RoomEnergyPropertiesAbridged$') = \
         'RoomEnergyPropertiesAbridged'
@@ -131,12 +134,12 @@ class RoomEnergyPropertiesAbridged(BaseModel):
 
     electric_equipment: ElectricEquipmentAbridged = Field(
         default=None,
-        description='ElectricEquipment object to describe the equipment usage.'
+        description='ElectricEquipment object to describe the electric equipment usage.'
     )
 
     gas_equipment: GasEquipmentAbridged = Field(
         default=None,
-        description='GasEquipment object to describe the equipment usage.'
+        description='GasEquipment object to describe the gas equipment usage.'
     )
 
     infiltration: InfiltrationAbridged = Field(
@@ -163,12 +166,16 @@ class TerrianTypes(str, Enum):
     city = 'City'
 
 
-class ModelEnergyProperties(BaseModel):
+class ModelEnergyProperties(NoExtraBaseModel):
 
     type: constr(regex='^ModelEnergyProperties$') = \
         'ModelEnergyProperties'
 
-    terrain_type: TerrianTypes = TerrianTypes.city
+    terrain_type: TerrianTypes = Field(
+        default=TerrianTypes.city,
+        description='Text for the terrain in which the model sits. This is used '
+            'to determine the wind profile over the height of the rooms.'
+    )
 
     global_construction_set: str = Field(
         default=None,
@@ -184,8 +191,9 @@ class ModelEnergyProperties(BaseModel):
         description='List of all ConstructionSets in the Model.'
     )
 
-    constructions: List[Union[OpaqueConstructionAbridged, WindowConstructionAbridged,
-                              ShadeConstruction]] = Field(
+    constructions: List[Union[
+        OpaqueConstructionAbridged, WindowConstructionAbridged,
+        ShadeConstruction, AirBoundaryConstructionAbridged]] = Field(
         ...,
         description='A list of all unique constructions in the model. This includes '
             'constructions across all Faces, Apertures, Doors, Shades, Room '
@@ -202,14 +210,14 @@ class ModelEnergyProperties(BaseModel):
             'materials needed to make the Model constructions.'
     )
 
-    hvacs: List[IdealAirSystemAbridged] = Field(
+    hvacs: List[Union[IdealAirSystemAbridged]] = Field(
         default=None,
-        description='List of all ProgramTypes in the Model.'
+        description='List of all HVAC systems in the Model.'
     )
 
     program_types: List[ProgramTypeAbridged] = Field(
         default=None,
-        description='List of all HVAC systems in the Model.'
+        description='List of all ProgramTypes in the Model.'
     )
 
     schedules: List[Union[ScheduleRulesetAbridged, ScheduleFixedIntervalAbridged]] = Field(
